==> java-1.2.3.tar.gz: java-1.2.3/dk.gov.oiosi.library/test/src/dk/gov/oiosi/test/service/OiosiServiceDelay.java <==
/*
 * The contents of this file are subject to the Mozilla Public
 * License Version 1.1 (the "License"); you may not use this
 * file except in compliance with the License. You may obtain
 * a copy of the License at http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an
 * "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either express
 * or implied. See the License for the specific language governing
 * rights and limitations under the License.
 *
 *
 * The Original Code is Java RASP toolkit.
 *
 * The Initial Developer of the Original Code is Lenio. Portions
 * created by Lenio are Copyright (C) 2007 Danish National IT and
 * Telecom Agency (http://www.itst.dk). All Rights Reserved.
 *
 * Contributor(s):
 *   Tommy Dejbjerg Pedersen, Lenio
 *   Hans Guldager Knudsen, Lenio
 *   Patrik Johansson, Accenture
 *   Dennis Sgaard, Accenture
 *   Martin Bentzen, Accenture
 *   Jesper Jensen, Avanade
 *   Ramzi Fadel, Avanade
 *   Christian Pedersen, Accenture
 *   Morten Hougesen, Accenture
 *   Mikkel Hippe Brun, ITST
 *   Finn Hartmann Jordal, ITST
 *   Christian Lanng, ITST
 *
 */

package dk.gov.oiosi.test.service;

import java.util.Map;

import org.apache.axiom.om.OMElement;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import dk.gov.oiosi.communication.OiosiMessage;
import dk.gov.oiosi.exception.MainException;

/**
 * interop service with delay in service invocation.
 */
public class OiosiServiceDelay extends OiosiService {

    /**
     * local log.
     */
    private static final Log log = LogFactory.getLog(OiosiServiceDelay.class);

    /*
     * (non-Javadoc)
     * 
     * @see dk.gov.oiosi.test.service.OiosiService#requestRespond(dk.gov.oiosi.communication.OiosiMessage)
     */
    public OiosiMessage requestRespond(OiosiMessage message) throws MainException {
        log.error("OIOSIServiceDelay.requestRespond Start");

        OMElement document = message.getMessageXml().getOMDocument();
        Map<String, Object> customHeaders = message.getMessageHeaders();
        String messageId = message.getMessageId();

        long sleep = -1;
        Object delayHeader = customHeaders.get("RaspInteropDelay");
        if (delayHeader == null) {
            MainException e = new MainException("Sender must supply customheader : RaspInteropDelay");
            e.setReceiverError(false);
            throw e;
        }
        try {
            sleep = Long.parseLong(delayHeader.toString());
        } catch (Exception e) {
            MainException me = new MainException("Sender must supply valid customheader : RaspInteropDelay : " + e);
            me.setReceiverError(false);
            throw me;
        }

        invokeCounter++;
        String msg = "Invokecount : " + invokeCounter + " : total/confirm/timeout/cancel/abort = " + invokeCounter + "/"
                + confirmCounter + "/" + timeoutCounter + "/" + faultedCounter + " : " + messageId;

        if (document == null) {
            log.info("OIOSI Test Service DELAYER Received empty document : " + sleep + "  " + msg);
        } else {
            log.info("OIOSI Test Service received DOCUMENT : " + messageId + " :: " + document.getLocalName() + " : " + msg);
        }

        log.info("- SLEEP sec : " + sleep);
        try {
            Thread.sleep(sleep * 1000);
        } catch (Exception ignore) {
        }

        log.info(" - RETURN NULL AS REPLY");
        return null;
    }

}

==> java-2.0.0.tar.gz: java-2.0.0/dk.gov.oiosi.library/test/src/dk/gov/oiosi/test/service/OiosiServiceDelay.java <==
/*
 * The contents of this file are subject to the Mozilla Public
 * License Version 1.1 (the "License"); you may not use this
 * file except in compliance with the License. You may obtain
 * a copy of the License at http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an
 * "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either express
 * or implied. See the License for the specific language governing
 * rights and limitations under the License.
 *
 *
 * The Original Code is Java RASP toolkit.
 *
 * The Initial Developer of the Original Code is Lenio. Portions
 * created by Lenio are Copyright (C) 2007 Danish National IT and
 * Telecom Agency (http://www.itst.dk). All Rights Reserved.
 */

package dk.gov.oiosi.test.service;

import dk.gov.oiosi.communication.OiosiMessage;
import dk.gov.oiosi.exception.MainException;
import org.apache.axiom.om.OMElement;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import java.util.Map;

/**
 * interop service with delay in service invocation.
 */
public class OiosiServiceDelay extends OiosiService {

    /**
     * local log.
     */
    private static final Log log = LogFactory.getLog(OiosiServiceDelay.class);

    /*
     * (non-Javadoc)
     *
     * @see dk.gov.oiosi.test.service.OiosiService#requestRespond(dk.gov.oiosi.communication.OiosiMessage)
     */
    public OiosiMessage requestRespond(OiosiMessage message) throws MainException {
        log.error("OIOSIServiceDelay.requestRespond Start");

        OMElement document = message.getMessageXml().getOMDocument();
        Map<String, Object> customHeaders = message.getMessageHeaders();
        String messageId = message.getMessageIdentifier();

        long sleep = -1;
        Object delayHeader = customHeaders.get("RaspInteropDelay");
        if (delayHeader == null) {
            MainException e = new MainException("Sender must supply customheader : RaspInteropDelay");
            e.setReceiverError(false);
            throw e;
        }
        try {
            sleep = Long.parseLong(delayHeader.toString());
        } catch (Exception e) {
            MainException me = new MainException("Sender must supply valid customheader : RaspInteropDelay : " + e);
            me.setReceiverError(false);
            throw me;
        }

        invokeCounter++;
        String msg = "Invokecount : " + invokeCounter + " : total/confirm/timeout/cancel/abort = " + invokeCounter + "/"
                + confirmCounter + "/" + timeoutCounter + "/" + faultedCounter + " : " + messageId;

        if (document == null) {
            log.info("OIOSI Test Service DELAYER Received empty document : " + sleep + "  " + msg);
        } else {
            log.info("OIOSI Test Service received DOCUMENT : " + messageId + " :: " + document.getLocalName() + " : " + msg);
        }

        log.info("- SLEEP sec : " + sleep);
        try {
            Thread.sleep(sleep * 1000);
        } catch (Exception ignore) {
        }

        log.info(" - RETURN NULL AS REPLY");
        return null;
    }

}
